@@ -10,8 +10,8 @@ EditProviderDialog::EditProviderDialog(QWidget *parent, SearchProvider *provider
     ui->setupUi(this);
     if(provider != NULL) {
         setWindowTitle("Edit Search Provider");
-        ui->txtName->setText(provider->name);
-        ui->txtAddress->setText(provider->baseUri);
+        ui->txtName->setText(provider->name());
+        ui->txtAddress->setText(provider->baseUri());
     } else {
         setWindowTitle("Add Search Provider");
     }
